@@ -14,12 +14,15 @@ def append_variant_info(main_curr, chunk_db):
     cmd = "attach ? as toMerge"
     main_curr.execute(cmd, (chunk_db, ))
 
+    main_curr.execute("BEGIN TRANSACTION")
     cmd = "INSERT INTO variants SELECT * FROM toMerge.variants"
     main_curr.execute(cmd)
 
     cmd = \
         "INSERT INTO variant_impacts SELECT * FROM toMerge.variant_impacts"
     main_curr.execute(cmd)
+    main_curr.execute("END TRANSACTION")
+
     cmd = "detach toMerge"
     main_curr.execute(cmd)
 
@@ -87,6 +90,33 @@ def append_version_info(main_curr, chunk_db):
     cmd = "detach toMerge"
     main_curr.execute(cmd)
 
+def append_gene_summary(main_curr, chunk_db):
+    """
+    Append the gene_summary from a chunk_db
+    to the main database.
+    """
+    cmd = "attach ? as toMerge"
+    main_curr.execute(cmd, (chunk_db, ))
+
+    cmd = "INSERT INTO gene_summary SELECT * FROM toMerge.gene_summary"
+    main_curr.execute(cmd)
+
+    cmd = "detach toMerge"
+    main_curr.execute(cmd)
+
+def append_gene_detailed(main_curr, chunk_db):
+    """
+    Append the gene_detailed from a chunk_db
+    to the main database.
+    """
+    cmd = "attach ? as toMerge"
+    main_curr.execute(cmd, (chunk_db, ))
+
+    cmd = "INSERT INTO gene_detailed SELECT * FROM toMerge.gene_detailed"
+    main_curr.execute(cmd)
+
+    cmd = "detach toMerge"
+    main_curr.execute(cmd)
 
 def update_sample_genotype_counts(main_curr, chunk_db):
     """
@@ -125,7 +155,6 @@ def merge_db_chunks(args):
 
     main_conn = sqlite3.connect(args.db)
     main_conn.isolation_level = None
-    main_conn.row_factory = sqlite3.Row
     main_curr = main_conn.cursor()
     main_curr.execute('PRAGMA synchronous = OFF')
     main_curr.execute('PRAGMA journal_mode=MEMORY')
@@ -148,10 +177,11 @@ def merge_db_chunks(args):
             append_sample_info(main_curr, db)
             append_resource_info(main_curr, db)
             append_version_info(main_curr, db)
+            append_gene_summary(main_curr, db)
+            append_gene_detailed(main_curr, db)
         else:
             update_sample_genotype_counts(main_curr, db)
 
-    gemini_db.create_indices(main_curr)
     main_conn.commit()
     main_curr.close()
 
