@@ -1,8 +1,8 @@
 #!/usr/bin/env python
-
 import os
 import sys
 from itertools import tee, ifilterfalse
+from collections import defaultdict
 
 # gemini imports
 import GeminiQuery
@@ -12,6 +12,7 @@ from gemini_region import add_region_to_query
 from gemini_subjects import (Subject, get_subjects, get_subjects_in_family,
                              get_family_dict)
 from gemini_utils import itersubclasses
+from dgidb import query_dgidb
 
 def all_samples_predicate(args):
     """ returns a predicate that returns True if, for a variant,
@@ -49,8 +50,6 @@ def select_subjects_predicate(subjects, args, subset=None):
         return all([p(row) for p in predicates])
     return predicate
 
-
-
 def variant_in_any_subject(subjects):
     def predicate(row):
         return subjects.intersection(samples_with_variant(row)) != set()
@@ -102,25 +101,52 @@ def needs_genotypes(args):
             args.show_families or 
             args.gt_filter)
 
+
+def needs_gene(args):
+    return (args.dgidb)
+
+
 def add_required_columns_to_query(args):
     if args.region:
         add_region_to_query(args)
 
+
 def run_query(args):
     predicates = get_row_predicates(args)
     add_required_columns_to_query(args)
     formatter = select_formatter(args)
     genotypes_needed = needs_genotypes(args)
+    gene_needed = needs_gene(args)
     gq = GeminiQuery.GeminiQuery(args.db, out_format=formatter)
     gq.run(args.query, args.gt_filter, args.show_variant_samples,
            args.sample_delim, predicates, genotypes_needed,
-           args.show_families)
+           gene_needed, args.show_families)
 
     if args.use_header and gq.header:
         print gq.header
 
-    for row in gq:
-        print row
+    if not args.dgidb:
+        for row in gq:
+            print row
+    else:
+        # collect a list of all the genes that need to be queried
+        # from DGIdb
+        genes = defaultdict()
+        for row in gq:
+            genes[row['gene']] = True
+
+        # collect info from DGIdb
+        dgidb_info = query_dgidb(genes)
+
+        # rerun the query (the cursor is now consumed)
+        gq = GeminiQuery.GeminiQuery(args.db, out_format=formatter)
+        gq.run(args.query, args.gt_filter, args.show_variant_samples,
+           args.sample_delim, predicates, genotypes_needed,
+           gene_needed, args.show_families)
+
+        # report the query results with DGIdb info added at the end.
+        for row in gq:  
+            print str(row) + "\t" + str(dgidb_info[row['gene']])
 
 
 def query(parser, args):
